@@ -45,6 +45,9 @@ class SwitchGuideStepStatusUiState(BaseModel):
     Attribute relevant for UI
     """
     lockStep: bool = False
+    """Indicates that we should return user to Summary step on Step Execution
+    """
+    returnToSummary: bool = False
 
 
 class SwitchGuideStepStatus(BaseModel):
